EXPORTS
	??1CBIODatabase@@UAE@XZ @ 1 NONAME ; public: virtual __thiscall CBIODatabase::~CBIODatabase(void)
	?AddAllBifsL@CBIODatabase@@QAEXAAVRFs@@@Z @ 2 NONAME ; public: void __thiscall CBIODatabase::AddAllBifsL(class RFs &)
	?AddBifL@CBIODatabase@@QAEXPAVCBioInfoFileReader@@@Z @ 3 NONAME ; public: void __thiscall CBIODatabase::AddBifL(class CBioInfoFileReader *)
	?BIOCount@CBIODatabase@@QAEHXZ @ 4 NONAME ; public: int __thiscall CBIODatabase::BIOCount(void)
	?BIOEntryLC@CBIODatabase@@QAEPBV?$CArrayFix@VTBioMsgId@@@@H@Z @ 5 NONAME ; public: class CArrayFix<class TBioMsgId> const * __thiscall CBIODatabase::BIOEntryLC(int)
	?BifReader@CBIODatabase@@QBEABVCBioInfoFileReader@@H@Z @ 6 NONAME ; public: class CBioInfoFileReader const & __thiscall CBIODatabase::BifReader(int)const 
	?BioEntryByTypeLC@CBIODatabase@@QAEPBV?$CArrayFix@VTBioMsgId@@@@W4TSearchList@1@W4TBioMsgIdType@@AAH@Z @ 7 NONAME ; public: class CArrayFix<class TBioMsgId> const * __thiscall CBIODatabase::BioEntryByTypeLC(enum CBIODatabase::TSearchList,enum TBioMsgIdType,int &)
	?GetBioControlID@CBIODatabase@@QAEXHAAVTUid@@@Z @ 8 NONAME ; public: void __thiscall CBIODatabase::GetBioControlID(int,class TUid &)
	?GetBioControlIDL@CBIODatabase@@QAEXVTUid@@AAV2@@Z @ 9 NONAME ; public: void __thiscall CBIODatabase::GetBioControlIDL(class TUid,class TUid &)
	?GetBioIndexWithMsgIDL@CBIODatabase@@QAEXVTUid@@AAH@Z @ 10 NONAME ; public: void __thiscall CBIODatabase::GetBioIndexWithMsgIDL(class TUid,int &)
	?GetBioIndexWithParserIDL@CBIODatabase@@QAEXVTUid@@AAH@Z @ 11 NONAME ABSENT ; public: void __thiscall CBIODatabase::GetBioIndexWithParserIDL(class TUid,int &)
	?GetBioMsgID@CBIODatabase@@QAEXHAAVTUid@@@Z @ 12 NONAME ; public: void __thiscall CBIODatabase::GetBioMsgID(int,class TUid &)
	?GetBioParserID@CBIODatabase@@QAEXHAAVTUid@@@Z @ 13 NONAME ABSENT ; public: void __thiscall CBIODatabase::GetBioParserID(int,class TUid &)
	?GetBioParserIDL@CBIODatabase@@QAEXVTUid@@AAV2@@Z @ 14 NONAME ABSENT ; public: void __thiscall CBIODatabase::GetBioParserIDL(class TUid,class TUid &)
	?GetDefaultSendBearerByTypeL@CBIODatabase@@QAEXVTUid@@W4TBioMsgIdType@@AAVTBioMsgId@@@Z @ 15 NONAME ; public: void __thiscall CBIODatabase::GetDefaultSendBearerByTypeL(class TUid,enum TBioMsgIdType,class TBioMsgId &)
	?GetDefaultSendBearerL@CBIODatabase@@QAEXVTUid@@AAVTBioMsgId@@@Z @ 16 NONAME ; public: void __thiscall CBIODatabase::GetDefaultSendBearerL(class TUid,class TBioMsgId &)
	?GetDefaultSendBearerTypeL@CBIODatabase@@QAEXVTUid@@AAW4TBioMsgIdType@@@Z @ 17 NONAME ; public: void __thiscall CBIODatabase::GetDefaultSendBearerTypeL(class TUid,enum TBioMsgIdType &)
	?GetFileExtL@CBIODatabase@@QAE?BVTPtrC16@@VTUid@@@Z @ 18 NONAME ; public: class TPtrC16 const  __thiscall CBIODatabase::GetFileExtL(class TUid)
	?GetIdentifierTextL@CBIODatabase@@QAEXVTUid@@W4TBioMsgIdType@@AAV?$TBuf@$0IA@@@@Z @ 19 NONAME ; public: void __thiscall CBIODatabase::GetIdentifierTextL(class TUid,enum TBioMsgIdType,class TBuf<128> &)
	?GetPortNumberL@CBIODatabase@@QAEXVTUid@@W4TBioMsgIdType@@AAH@Z @ 20 NONAME ; public: void __thiscall CBIODatabase::GetPortNumberL(class TUid,enum TBioMsgIdType,int &)
	?IsBioMessageL@CBIODatabase@@QAEHVTBioMsgId@@AAVTUid@@@Z @ 21 NONAME ; public: int __thiscall CBIODatabase::IsBioMessageL(class TBioMsgId,class TUid &)
	?IsBioMessageL@CBIODatabase@@QAEHW4TBioMsgIdType@@ABVTDesC16@@GAAVTUid@@@Z @ 22 NONAME ; public: int __thiscall CBIODatabase::IsBioMessageL(enum TBioMsgIdType,class TDesC16 const &,unsigned short,class TUid &)
	?NewL@CBIODatabase@@SAPAV1@AAVRFs@@@Z @ 23 NONAME ; public: static class CBIODatabase * __cdecl CBIODatabase::NewL(class RFs &)
	?NewL@CBifChangeObserver@@SAPAV1@AAVMBifChangeObserver@@AAVRFs@@@Z @ 24 NONAME ; public: static class CBifChangeObserver * __cdecl CBifChangeObserver::NewL(class MBifChangeObserver &,class RFs &)
	?NewLC@CBIODatabase@@SAPAV1@AAVRFs@@@Z @ 25 NONAME ; public: static class CBIODatabase * __cdecl CBIODatabase::NewLC(class RFs &)
	?RemoveBifL@CBIODatabase@@QAEXH@Z @ 26 NONAME ; public: void __thiscall CBIODatabase::RemoveBifL(int)
	?RemoveBifL@CBIODatabase@@QAEXVTUid@@@Z @ 27 NONAME ; public: void __thiscall CBIODatabase::RemoveBifL(class TUid)
	?Start@CBifChangeObserver@@QAEXXZ @ 28 NONAME ; public: void __thiscall CBifChangeObserver::Start(void)
	?GetBioParserName@CBIODatabase@@QAE?BVTPtrC16@@H@Z @ 29 NONAME ; class TPtrC16 const CBIODatabase::GetBioParserName(int)
	?GetBioParserNameL@CBIODatabase@@QAE?BVTPtrC16@@VTUid@@@Z @ 30 NONAME ; class TPtrC16 const CBIODatabase::GetBioParserNameL(class TUid)
	?IsBioParserSecure@CBIODatabase@@QAEHH@Z @ 31 NONAME ABSENT ; int CBIODatabase::IsBioParserSecure(int)
	?IsBioParserSecureL@CBIODatabase@@QAEHVTUid@@@Z @ 32 NONAME ABSENT ; int CBIODatabase::IsBioParserSecureL(class TUid)
	?GetBioControlName@CBIODatabase@@QAE?BVTPtrC16@@H@Z @ 33 NONAME ; class TPtrC16 const CBIODatabase::GetBioControlName(int)
	?GetBioControlNameL@CBIODatabase@@QAE?BVTPtrC16@@VTUid@@@Z @ 34 NONAME ; class TPtrC16 const CBIODatabase::GetBioControlNameL(class TUid)

